@@ -59,6 +59,7 @@ class _LogConf:
         self.__conf_error_file = None       # 错误日志保存地址
         self.__detail = False               # 是否显示详细日志信息，原Debug参数
         self.__device = platform.system()
+        self.__log_deep = 2                 # 设置Logger深度
         if self.__device == 'Windows':
             os.system("")
 
@@ -125,13 +126,23 @@ class _LogConf:
     def device(self):
         return self.__device
 
+    @property
+    def deep(self):
+        return self.__log_deep
+
+    @deep.setter
+    def deep(self, set_val):
+        if type(set_val) is not int:
+            raise ValueError("输入的深度值必须是一个整数")
+        else:
+            self.__log_deep = set_val
 
 log_conf = _LogConf()
 
 '''定义关于日志输出的格式'''
 
 class _LogConfig:
-    def __init__(self, deep=2):
+    def __init__(self, deep=log_conf.deep):
         self.num = deep
 
     def conf_success(self, *args) -> str:
